.. _changelog:

*********
Changelog
*********

This page contains a change log, generated for package releases.
The corresponding issues and pull requests can be found `on
Github <https://github.com/solo-spice/sospice/>`__

.. include:: ../../CHANGELOG.rst
